==> ejc-doc-impl-3.0.0-20201126.013745-1-sources.jar: com/ejianc/business/doc/bean/DocCategoryEntity.java <==
package com.ejianc.business.doc.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 文档分类
 * 
 * @author generator
 * 
 */
 @TableName("ejc_doc_category")
public class DocCategoryEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

	@TableField(value = "category_name")
	private String categoryName; // 分类名称

	@TableField(value = "required")
	private String required; // 是否必传，1是0否

	@TableField(value = "enabled")
	private String enabled; // 启停用，1启用0停用

	@TableField(value = "num")
	private Long num; // 上传个数

	@TableField(value = "pid")
	private Long pid; // 父id

	@TableField(value = "parent_name")
	private String parentName; // 父名称

	@TableField(value = "inner_code")
	private String innerCode; // 分类内码

	public String getCategoryName() {
		return categoryName;
	}

	public void setCategoryName(String categoryName) {
		this.categoryName = categoryName;
	}

	public String getRequired() {
		return required;
	}

	public void setRequired(String required) {
		this.required = required;
	}

	public Long getNum() {
		return num;
	}

	public void setNum(Long num) {
		this.num = num;
	}

	public Long getPid() {
		return pid;
	}

	public void setPid(Long pid) {
		this.pid = pid;
	}

	public String getParentName() {
		return parentName;
	}

	public void setParentName(String parentName) {
		this.parentName = parentName;
	}

	public String getInnerCode() {
		return innerCode;
	}

	public void setInnerCode(String innerCode) {
		this.innerCode = innerCode;
	}

	public String getEnabled() {
		return enabled;
	}

	public void setEnabled(String enabled) {
		this.enabled = enabled;
	}
    
}

==> ejc-doc-impl-3.0.0-20201127.114543-4-sources.jar: com/ejianc/business/doc/bean/DocCategoryEntity.java <==
package com.ejianc.business.doc.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 文档分类
 * 
 * @author generator
 * 
 */
 @TableName("ejc_doc_category")
public class DocCategoryEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

	@TableField(value = "category_name")
	private String categoryName; // 分类名称

	@TableField(value = "required")
	private String required; // 是否必传，1是0否

	@TableField(value = "enabled")
	private String enabled; // 启停用，1启用0停用

	@TableField(value = "num")
	private Long num; // 上传个数

	@TableField(value = "parent_id")
	private Long parentId; // 父id

	@TableField(value = "parent_name")
	private String parentName; // 父名称

	@TableField(value = "inner_code")
	private String innerCode; // 分类内码

	public String getCategoryName() {
		return categoryName;
	}

	public void setCategoryName(String categoryName) {
		this.categoryName = categoryName;
	}

	public String getRequired() {
		return required;
	}

	public void setRequired(String required) {
		this.required = required;
	}

	public Long getNum() {
		return num;
	}

	public void setNum(Long num) {
		this.num = num;
	}

	public Long getParentId() {
		return parentId;
	}

	public void setParentId(Long parentId) {
		this.parentId = parentId;
	}

	public String getParentName() {
		return parentName;
	}

	public void setParentName(String parentName) {
		this.parentName = parentName;
	}

	public String getInnerCode() {
		return innerCode;
	}

	public void setInnerCode(String innerCode) {
		this.innerCode = innerCode;
	}

	public String getEnabled() {
		return enabled;
	}

	public void setEnabled(String enabled) {
		this.enabled = enabled;
	}
    
}
